@@ -294,7 +294,7 @@ enum {
   SPVM_OPCODE_C_ID_IF_EXCEPTION_RETURN,
   SPVM_OPCODE_C_ID_ISA,
   SPVM_OPCODE_C_ID_IS_TYPE,
-  SPVM_OPCODE_C_ID_HAS_IMPL,
+  SPVM_OPCODE_C_ID_CAN,
   SPVM_OPCODE_C_ID_PRINT,
   SPVM_OPCODE_C_ID_SAY,
   SPVM_OPCODE_C_ID_WARN,
